/* menuclear - Clear the menu entries */
/* Author: Cyrille Pontvieux <jrd@enialis.net>
 * Licence: GPL v3+ */

#include <grub/types.h>
#include <grub/misc.h>
#include <grub/err.h>
#include <grub/dl.h>
#include <grub/extcmd.h>
#include <grub/normal.h>
#include <grub/i18n.h>

GRUB_MOD_LICENSE ("GPLv3+");

static grub_err_t
grub_cmd_menuclear (grub_command_t cmd __attribute__ ((unused)), int argc __attribute__ ((unused)), char **args __attribute__ ((unused)))
{
  grub_menu_t menu;
  menu = grub_env_get_menu ();
  if (! menu)
  {
    /* Nothing to do */
    grub_dprintf ("menuclear", "no menu to clear\n");
    return GRUB_ERR_NONE;
  }
  grub_dprintf ("menuclear", "freeing menu\n");
  grub_normal_free_menu (menu);
  grub_dprintf ("menuclear", "menu destroyed\n");
  menu = grub_zalloc (sizeof (*menu));
  if (! menu)
    return grub_errno;
  grub_env_set_menu (menu);
  return GRUB_ERR_NONE;
}

static grub_command_t cmd;

GRUB_MOD_INIT (menuclear)
{
  cmd = grub_register_command ("menuclear", grub_cmd_menuclear,
			      "",
			      N_("Clear the menu items added by menuentry command."));
}

GRUB_MOD_FINI (menuclear)
{
  grub_unregister_command (cmd);
}
